#include "alloc.h"
#include "defs.h"

#define DO_MEMORY_PINNING

namespace sys {

char *gpu_alloc(size_t size) {
    char *ptr;
    HIP_CALL(hipMalloc((void**)&ptr, size));
    HIP_CALL(hipMemset(ptr, 0, sizeof(size)));
    return ptr;
}

void gpu_free(void *ptr) {
    HIP_CALL(hipFree(ptr));
}

char *cpu_alloc(size_t size) {
    char *ptr;
    ptr = (char *)calloc(size, 1);
#ifdef DO_MEMORY_PINNING
    HIP_CALL(hipHostRegister(ptr, size, hipHostRegisterDefault));
#endif
    return ptr;
}

void cpu_free(void *ptr) {
#ifdef DO_MEMORY_PINNING
    HIP_CALL(hipHostUnregister(ptr));
#endif
    free(ptr);
}

}

